@@ -3,7 +3,9 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
   warning = FALSE,
-  message = FALSE
+  message = FALSE,
+  fig.width = 7,
+  fig.height = 4
 )
 
 ## ----setup, echo = FALSE------------------------------------------------------
